==> editor_advanced_link-2.1.2.tar.gz: editor_advanced_link/js/ckeditor5_plugins/editorAdvancedLink/src/details/detailsview.js <==
/**
 * @module ui/details/detailsview
 */

import { View } from 'ckeditor5/src/ui';

/**
 * The class component representing a details element. It should be used in more
 * advanced forms to group fields.
 *
 * @extends module:ui/view~View
 */
export default class DetailsView extends View {
  /**
   * Creates an instance of the details class.
   *
   * @param {module:utils/locale~Locale} locale The locale instance.
   * @param {Object} options
   * @param {String} options.summary The summary.
   * @param {String} [options.class] An additional class.
   */
  constructor( locale, options = {} ) {
    super( locale );

    const bind = this.bindTemplate;

    /**
     * The summary of the details element.
     *
     * @observable
     * @member {String} #summary
     */
    this.set( 'summary', options.summary || '' );

    /**
     * An additional CSS class added to the {@link #element}.
     *
     * @observable
     * @member {String} #class
     */
    this.set( 'class', options.class || null );

    /**
     * A collection of items.
     *
     * @readonly
     * @member {module:ui/viewcollection~ViewCollection}
     */
    this.children = this.createCollection();

    this.setTemplate( {
      tag: 'details',
      attributes: {
        class: [
          'ck',
          'ck-form__details',
          bind.to( 'class' )
        ]
      },
      children: this.children
    } );

    const summary = new View( locale );

    summary.setTemplate( {
      tag: 'summary',
      attributes: {
        class: [
          'ck',
          'ck-form__details__summary'
        ]
      },
      children: [
        { text: bind.to( 'summary' ) }
      ]
    } );

    this.children.add( summary );
  }
}

==> editor_advanced_link-2.2.1.tar.gz: editor_advanced_link/js/ckeditor5_plugins/editorAdvancedLink/src/details/detailsview.js <==
/**
 * @module ui/details/detailsview
 */

// eslint-disable-next-line import/no-extraneous-dependencies
import { View } from 'ckeditor5/src/ui';

/**
 * The class component representing a details element. It should be used in more
 * advanced forms to group fields.
 *
 * @extends module:ui/view~View
 */
export default class DetailsView extends View {
  /**
   * Creates an instance of the details class.
   *
   * @param {module:utils/locale~Locale} locale The locale instance.
   * @param {Object} options The options.
   * @param {String} options.summary The summary.
   * @param {String} [options.class] An additional class.
   */
  constructor(locale, options = {}) {
    super(locale);

    const bind = this.bindTemplate;

    /**
     * The summary of the details element.
     *
     * @observable
     * @member {String} #summary
     */
    this.set('summary', options.summary || '');

    /**
     * An additional CSS class added to the {@link #element}.
     *
     * @observable
     * @member {String} #class
     */
    this.set('class', options.class || null);

    /**
     * A collection of items.
     *
     * @readonly
     * @member {module:ui/viewcollection~ViewCollection}
     */
    this.children = this.createCollection();

    this.setTemplate({
      tag: 'details',
      attributes: {
        class: ['ck', 'ck-form__details', bind.to('class')],
      },
      children: this.children,
    });

    const summary = new View(locale);

    summary.setTemplate({
      tag: 'summary',
      attributes: {
        class: ['ck', 'ck-form__details__summary'],
      },
      children: [{ text: bind.to('summary') }],
    });

    this.children.add(summary);
  }
}
